Days of the Dead - Qualifier for the 2002 Australian Championship Sydney, Australia August 18th 2002 13 players Chris Arthur Deck Name: Rutor's Followers Some bleed, some bloat and plenty of stealth. If things are going well summon Qufur or Samat and Rutor them. If not, summon Hesha, load up with blood dolls, the razor and a secure haven and survive until things get better. Amam and Jake are great to throw in front of rush combat. Plus it's ok if a few vamps go to torpor because you can bring them out easily with humanitas and catacombs. Nice if you can get either on a secured vamp early. Bloat is pretty much the only defence against votes and bleed but with a small library the deck moves quickly and you can be gaining 3-4 pool a turn before other players become threatening. Crypt (12 cards, min=12, max=26, avg=4.75) ------------------------------------------ 1x Qufur am-Heru 7 OBF PRE SER cel tha Follower of Set:2 1x Sarrasine 7 OBF PRE aus nec ser Follower of Set:2 1x Hesha Ruhadze 6 SER ani obf pre Follower of Set:2 1x Samat Ramal-Ra, Archon 6 OBF pre ser tha Follower of Set:2 1x Count Ormonde 5 OBF dom pre ser Follower of Set:2 1x Dedefra 5 SER nec obf Follower of Set:2 1x Sir Marriot D'Urban 5 PRE aus obf ser Follower of Set:2 1x Hadrian Garrick 4 obf pre Follower of Set:2 1x Nepata 4 obf pre ser Follower of Set:2 1x Celine Chevalier 3 obf ser Follower of Set:2 1x Khalil Anvari 3 pre ser Follower of Set:2 1x Lalitha 2 ser Follower of Set:2 Library (67 cards) Master (14) 6x Blood Doll 1x Dreams of the Sphinx 1x Giant's Blood 1x Humanitas 1x Jake Washington 1x Opium Den 1x Rack, The -- maybe swap out for Barrens 1x Secure Haven 1x Temple Hunting Ground Action (19) 1x Arson 6x Enchant Kindred 1x Enticement 1x Entrancement 3x Rutor's Hand 1x Sanguine Instruction 5x Summon the Serpent 1x Temptation Ally (1) 1x Amam the Devourer Equipment (4) 1x Aaron's Feeding Razor 1x Catacombs 1x Palatial Estate 1x Signet of King Saul, The Retainer (3) 1x J. S. Simmons, Esq. 1x Priestess of Sekhmet 1x Tasha Morgan Action Modifier (18) 2x Change of Target 4x Cloak the Gathering 5x Faceless Night 4x Lost in Crowds 3x Spying Mission Action Modifier/Combat (4) 4x Swallowed by the Night Reaction (2) 2x Ecstasy Combat (2) 2x Majesty -- after CE probably swap out for dodge, ecstasy, change of target